@@ -121,6 +121,7 @@ __all__ = (
     "PrometheusInfoTypeDef",
     "PrometheusTypeDef",
     "ProvisionedRequestTypeDef",
+    "ProvisionedThroughputTypeDef",
     "ProvisionedTypeDef",
     "PublicAccessTypeDef",
     "RebootBrokerRequestRequestTypeDef",
@@ -196,13 +197,27 @@ BatchDisassociateScramSecretResponseTypeDef = TypedDict(
     },
 )
 
-BrokerEBSVolumeInfoTypeDef = TypedDict(
-    "BrokerEBSVolumeInfoTypeDef",
+_RequiredBrokerEBSVolumeInfoTypeDef = TypedDict(
+    "_RequiredBrokerEBSVolumeInfoTypeDef",
     {
         "KafkaBrokerNodeId": str,
-        "VolumeSizeGB": int,
     },
 )
+_OptionalBrokerEBSVolumeInfoTypeDef = TypedDict(
+    "_OptionalBrokerEBSVolumeInfoTypeDef",
+    {
+        "ProvisionedThroughput": "ProvisionedThroughputTypeDef",
+        "VolumeSizeGB": int,
+    },
+    total=False,
+)
+
+
+class BrokerEBSVolumeInfoTypeDef(
+    _RequiredBrokerEBSVolumeInfoTypeDef, _OptionalBrokerEBSVolumeInfoTypeDef
+):
+    pass
+
 
 BrokerLogsTypeDef = TypedDict(
     "BrokerLogsTypeDef",
@@ -674,6 +689,7 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
 EBSStorageInfoTypeDef = TypedDict(
     "EBSStorageInfoTypeDef",
     {
+        "ProvisionedThroughput": "ProvisionedThroughputTypeDef",
         "VolumeSize": int,
     },
     total=False,
@@ -1138,6 +1154,15 @@ class ProvisionedRequestTypeDef(
     pass
 
 
+ProvisionedThroughputTypeDef = TypedDict(
+    "ProvisionedThroughputTypeDef",
+    {
+        "Enabled": bool,
+        "VolumeThroughput": int,
+    },
+    total=False,
+)
+
 _RequiredProvisionedTypeDef = TypedDict(
     "_RequiredProvisionedTypeDef",
     {
